#ifndef DEFINES_H
 #define DEFINES_H
 #include <defines.h>
#endif

void clear_crc32();
word32 get_crc32();
void crc32(void *, int);
void init_crc32();
